@@ -24,7 +24,7 @@ test_initializer("random_uniform")
 test_initializer("truncated_normal")
 test_initializer("variance_scaling")
 test_initializer("orthogonal")
-if (have_keras())
+if (is_keras_available())
   if (is_keras_implementation() || (is_tensorflow_implementation() && (tensorflow::tf_version() <= "1.1")))
     test_initializer("identity") # don't know why this test fails on v1.2
 test_initializer("glorot_normal")
@@ -32,7 +32,7 @@ test_initializer("glorot_uniform")
 test_initializer("he_uniform")
 test_initializer("he_normal")
 test_initializer("lecun_uniform")
-test_initializer("lecun_normal", required_version = "2.0.5")
+test_initializer("lecun_normal", required_version = "2.0.6")
 
 
 
